@@ -4,7 +4,7 @@ use public_api::{public_api_from_rustdoc_json_str, Options};
 
 fn main() -> Result<(), Box<dyn Error>> {
     let public_api = public_api_from_rustdoc_json_str(
-        &read_to_string("./tests/rustdoc_json/public_api-v0.4.0.json")?,
+        &read_to_string("./tests/rustdoc-json/example_api-v0.2.0.json")?,
         Options::default(),
     )?;
 
